@@ -2,6 +2,6 @@
 
 __author__ = """Jim Vogel"""
 __email__ = "james.vogel@capspire.com"
-__version__ = "0.1.34"
+__version__ = "0.3.1"
 
-from tank_forecaster.tank_forecaster import forecast_near, forecast_far, clean
+from tank_forecaster import decomp, events, forecaster, validation
